@@ -544,7 +544,7 @@ static void testReadInLine_4(){
     //last xline
     int last_line = (crosslines_sz-1);
     //first sample
-    assertClose(4.24f, data[samples*last_line+0], 0);
+    assertClose(4.24f, data[samples*last_line+0], 0.0001f);
     //middle sample
     assertClose(4.24024f, data[samples*last_line+samples/2-1], 0.0001);
     //last sample
@@ -878,6 +878,7 @@ static void test_file_size_above_4GB(){
     long long pos = segy_ftell( fp );
     assertTrue(pos > (long long)INT_MAX, "pos smaller than INT_MAX. "
                               "This means there's an overflow somewhere" );
+    assertTrue(pos != -1, "overflow in off_t");
     assertTrue(pos == trace * tracesize, "seek overflow");
     segy_close(fp);
 }
